Module docker

Module docker 

Docker client helpers used by both natmap and auto-discover.

Functions

connect
Connect to the local Docker daemon via the default socket or DOCKER_HOST env var.
trim_container_name
Strip the leading / that Docker prepends to container names.