pub fn create_freebind_socket(addr: &SocketAddr) -> Result<Socket>Expand description
Creates and configures a Socket for addr with SO_REUSEADDR
and the appropriate IP_FREEBIND option.
pub fn create_freebind_socket(addr: &SocketAddr) -> Result<Socket>Creates and configures a Socket for addr with SO_REUSEADDR
and the appropriate IP_FREEBIND option.