Docker client helpers used by both natmap and auto-discover.
Functions
- connect
- Connect to the local Docker daemon via the default socket or
DOCKER_HOSTenv var. - trim_
container_ name - Strip the leading
/that Docker prepends to container names.